@@ -12,7 +12,7 @@ class ReportGetV3(ZADOpenAPIV3):
         """
         Gets a generation status of report by id
         """
-        path = f'/v2/reports/{report_id}'
+        path = f'/reporting/reports/{report_id}'
         return self.get(path)
 
 
